==> fxusb-suse8.1-03.10.02.tar.gz: fritz/src.drv/defs.h <==
/* 
 * defs.h
 * Copyright (C) 2002, AVM GmbH. All rights reserved.
 * 
 * This Software is  free software. You can redistribute and/or
 * modify such free software under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * The free software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this Software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA, or see
 * http://www.opensource.org/licenses/lgpl-license.html
 * 
 * Contact: AVM GmbH, Alt-Moabit 95, 10559 Berlin, Germany, email: info@avm.de
 */

#ifndef __have_defs_h__
#define __have_defs_h__

#ifndef LINUX_VERSION_CODE
# include <linux/version.h>
#endif

#ifndef TRUE
# define TRUE		(1==1)
# define FALSE		(1==0)
#endif

/*---------------------------------------------------------------------------*\
\*---------------------------------------------------------------------------*/
#if defined (__fcusb__)
# define PRODUCT_LOGO	"AVM FRITZ!Card USB"
# define INTERFACE	"usb"
#elif defined (__fcusb2__)
# define PRODUCT_LOGO	"AVM FRITZ!Card USB v2"
# define INTERFACE	"usb"
#elif defined (__fxusb__)
# define PRODUCT_LOGO	"AVM FRITZ!X USB"
# define INTERFACE	"usb"
#else
# error You have to define a card identifier...
#endif
#define  DRIVER_LOGO    PRODUCT_LOGO " driver"
#define  SHORT_LOGO	"fritz-" INTERFACE

#define	REV_DEFAULT	"0.2"

#if defined (__fcusb__) || defined (__fcusb2__) || defined (__fxusb__)
# define __usb__
#endif

/*---------------------------------------------------------------------------*\
\*---------------------------------------------------------------------------*/
#if defined (OSDEBUG) && defined (NDEBUG)
# undef NDEBUG
#endif

/*---------------------------------------------------------------------------*\
 * LOG_MESSAGES - CAPI trace
 * LOG_TIMER - Activate debug timers
\*---------------------------------------------------------------------------*/
#define LOG_TIMER

#define	UNUSED_ARG(x)	(x)=(x)

/*---------------------------------------------------------------------------*\
\*---------------------------------------------------------------------------*/
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,43)
# define KFREE_SKB(x)	dev_kfree_skb(x)
#else
# include <linux/netdevice.h>
# define KFREE_SKB(x)	dev_kfree_skb_any(x)
#endif

#endif

==> fxusb-suse8.2-03.11.02.tar.gz: fritz/src.drv/defs.h <==
/* 
 * defs.h
 * Copyright (C) 2002, AVM GmbH. All rights reserved.
 * 
 * This Software is  free software. You can redistribute and/or
 * modify such free software under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * The free software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this Software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA, or see
 * http://www.opensource.org/licenses/lgpl-license.html
 * 
 * Contact: AVM GmbH, Alt-Moabit 95, 10559 Berlin, Germany, email: info@avm.de
 */

#ifndef __have_defs_h__
#define __have_defs_h__

#ifndef LINUX_VERSION_CODE
# include <linux/version.h>
#endif

#ifndef TRUE
# define TRUE		(1==1)
# define FALSE		(1==0)
#endif

/*---------------------------------------------------------------------------*\
\*---------------------------------------------------------------------------*/
#if defined (__fcusb__)
# define PRODUCT_LOGO	"AVM FRITZ!Card USB"
# define INTERFACE	"usb"
#elif defined (__fcusb2__)
# define PRODUCT_LOGO	"AVM FRITZ!Card USB v2"
# define INTERFACE	"usb"
#elif defined (__fxusb__)
# define PRODUCT_LOGO	"AVM FRITZ!X USB/FRITZ!X ISDN"
# define INTERFACE	"usb"
#else
# error You have to define a card identifier...
#endif
#define  DRIVER_LOGO    PRODUCT_LOGO " driver"
#define  SHORT_LOGO	"fritz-" INTERFACE

#define	REV_DEFAULT	"0.4.2"

#if defined (__fcusb__) || defined (__fcusb2__) || defined (__fxusb__)
# define __usb__
#endif

/*---------------------------------------------------------------------------*\
\*---------------------------------------------------------------------------*/
#if defined (OSDEBUG) && defined (NDEBUG)
# undef NDEBUG
#endif

/*---------------------------------------------------------------------------*\
 * LOG_MESSAGES - CAPI trace
 * LOG_ALLOC - Log heap activity
 * LOG_TIMER - Activate debug timers
\*---------------------------------------------------------------------------*/

#define	UNUSED_ARG(x)	(x)=(x)

/*---------------------------------------------------------------------------*\
\*---------------------------------------------------------------------------*/
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,43)
# define KFREE_SKB(x)	dev_kfree_skb(x)
#else
# include <linux/netdevice.h>
# define KFREE_SKB(x)	dev_kfree_skb_any(x)
#endif

#endif
